@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Data::Hive;
 # ABSTRACT: convenient access to hierarchical data
-$Data::Hive::VERSION = '1.012';
+$Data::Hive::VERSION = '1.013';
 use Carp ();
 
 #pod =head1 SYNOPSIS
@@ -458,7 +458,7 @@ Data::Hive - convenient access to hierarchical data
 
 =head1 VERSION
 
-version 1.012
+version 1.013
 
 =head1 SYNOPSIS
 
@@ -742,6 +742,22 @@ Ricardo Signes <rjbs@cpan.org>
 
 =back
 
+=head1 CONTRIBUTORS
+
+=for stopwords hdp rjbs
+
+=over 4
+
+=item *
+
+hdp <hdp@1bcdbe44-fcfd-0310-b51b-975661d93aa0>
+
+=item *
+
+rjbs <rjbs@1bcdbe44-fcfd-0310-b51b-975661d93aa0>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2006 by Hans Dieter Pearcey.
